Struct RegisterBlock
Source pub struct RegisterBlock { }
0x04 - PWM Enable Register
0x08 - PWM Disable Register
0x0c - PWM Status Register
0x10 - PWM Interrupt Enable Register
0x14 - PWM Interrupt Disable Register
0x18 - PWM Interrupt Mask Register
0x1c - PWM Interrupt Status Register
0x200 - PWM Channel Mode Register (ch_num = 0)
0x204 - PWM Channel Duty Cycle Register (ch_num = 0)
0x208 - PWM Channel Period Register (ch_num = 0)
0x20c - PWM Channel Counter Register (ch_num = 0)
0x210 - PWM Channel Update Register (ch_num = 0)
0x220 - PWM Channel Mode Register (ch_num = 1)
0x224 - PWM Channel Duty Cycle Register (ch_num = 1)
0x228 - PWM Channel Period Register (ch_num = 1)
0x22c - PWM Channel Counter Register (ch_num = 1)
0x230 - PWM Channel Update Register (ch_num = 1)
0x240 - PWM Channel Mode Register (ch_num = 2)
0x244 - PWM Channel Duty Cycle Register (ch_num = 2)
0x248 - PWM Channel Period Register (ch_num = 2)
0x24c - PWM Channel Counter Register (ch_num = 2)
0x250 - PWM Channel Update Register (ch_num = 2)
0x260 - PWM Channel Mode Register (ch_num = 3)
0x264 - PWM Channel Duty Cycle Register (ch_num = 3)
0x268 - PWM Channel Period Register (ch_num = 3)
0x26c - PWM Channel Counter Register (ch_num = 3)
0x270 - PWM Channel Update Register (ch_num = 3)
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.